@@ -111,7 +111,7 @@ def install_requirements():
     exclude_path = os.path.join(repo_path, 'requirements_exclude.txt')
     if not os.path.exists(exclude_path):
         exclude_path = False
-    reqgen.generate_merged_file(full, instance, exclude_path)
+    reqgen.generate_merged_file(full, instance, exclude=exclude_path)
     cmd = 'pip install -r %s' % (full)
     subprocess.check_call(shlex.split(cmd))
     # Uninstall the requirements_exclude.txt if the path exists.
